@@ -4,6 +4,7 @@
  * Proprietary and confidential
  * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
 """
+
 from django.core.management.base import BaseCommand
 
 from artd_location.data.cities import CITIES
@@ -24,7 +25,7 @@ class Command(BaseCommand):
                     code=city[1],
                     region=region,
                 )
-                print(f"{city[3]} was created")
+                self.stdout.write(self.style.SUCCESS(f"{city[3]} was created"))
             else:
                 city_obj = City.objects.get(
                     id=city[0],
@@ -34,4 +35,4 @@ class Command(BaseCommand):
                 city_obj.code = city[1]
                 city_obj.region = region
                 city_obj.save()
-                print(f"{city[3]} was updated")
+                self.stdout.write(self.style.WARNING(f"{city[3]} was updated"))
