@@ -4,6 +4,7 @@
  * Proprietary and confidential
  * Written by Jonathan Favian Urzola Maldonado <jonathan@artd.com.co>, 2023
 """
+
 from django.core.management.base import BaseCommand
 
 from artd_location.data.countries import COUNTRIES
@@ -25,7 +26,7 @@ class Command(BaseCommand):
                     iso3=country[5],
                     phone_code=country[6],
                 )
-                print(f"{country[1]} was created")
+                self.stdout.write(self.style.SUCCESS(f"{country[1]} was created"))
             else:
                 country_obj = Country.objects.get(
                     id=country[0],
@@ -37,4 +38,4 @@ class Command(BaseCommand):
                 country_obj.iso3 = country[5]
                 country_obj.phone_code = country[6]
                 country_obj.save()
-                print(f"{country[1]} was updated")
+                self.stdout.write(self.style.WARNING(f"{country[1]} was updated"))
